@@ -26,7 +26,7 @@ adjust_hcl <- function(col, h = 0, c = 0, l = 0, method = "relative", fixup = TR
     alpha <- format(as.hexmode(col[4L, ]), width = 2L, upper.case = TRUE)
     alpha[alpha == "FF"] <- ""
     ## retain only RGB
-    col <- RGB(t(col[1L:3L, ])/255)
+    col <- sRGB(t(col[1L:3L, ])/255)
   }
   
   ## convert to HCL and remove chroma
@@ -87,7 +87,7 @@ lightdark <- function(col, amount = 0.1,
     alpha <- format(as.hexmode(col[4L, ]), width = 2L, upper.case = TRUE)
     alpha[alpha == "FF"] <- ""
     ## retain only RGB
-    col <- RGB(t(col[1L:3L, ])/255)
+    col <- sRGB(t(col[1L:3L, ])/255)
   }
   
   if(space == "HCL") {
@@ -182,8 +182,8 @@ if ( FALSE ) {
    # ----------------------------------------------------------------
    multiverge_hcl <- function(n,h=c(10,100,230,290),l=60,lmax=90,fixup=FALSE) {
 
-      C <- seq(0,min(max_chroma(h,l)),length=n)
-      L <- seq(lmax,l,length=n)
+      C <- seq(0, min(max_chroma(h,l)), length.out = n)
+      L <- seq(lmax, l, length.out = n)
       cols <- matrix("NA",ncol=length(h),nrow=n)
       for ( i in 1:ncol(cols) ) {
          cols[,i] <- hex(polarLUV(H=h[i],C=C,L=L),fixup)
@@ -273,7 +273,7 @@ lightdark2 <- function(col, amount = 0.1,
     alpha <- format(as.hexmode(col[4L, ]), width = 2L, upper.case = TRUE)
     alpha[alpha == "FF"] <- ""
     ## retain only RGB
-    col <- RGB(t(col[1L:3L, ])/255)
+    col <- sRGB(t(col[1L:3L, ])/255)
   }
   
   if (space == "HCL") {
